smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl

# ``smartcard`.`wx`.`CardAndReaderTreePanel`.`ReaderTreeCtrl``

class documentation

`class ReaderTreeCtrl(BaseCardTreeCtrl):`

View In Hierarchy

The ReaderTreeCtrl monitors inserted cards and readers and notifies the application client dialog of any card activation.

Method | `__init__` | Constructor. Create a reader tree control.
Method | `AddATR` | Add an ATR to a reader node.
Method | `GetATR` | Return the ATR of the card inserted into the reader.
Method | `OnAddCards` | Called when a card is inserted. Adds the smart card child to the reader node.
Method | `OnAddReaders` | Called when a reader is inserted. Adds the smart card reader to the smartcard readers tree.
Method | `OnRemoveCards` | Called when a card is removed. Removes the card from the tree.
Method | `OnRemoveReaders` | Called when a reader is removed. Removes the reader from the smartcard readers tree.
Instance Variable | `mutex` | Undocumented
Instance Variable | `root` | Undocumented

Inherited from `BaseCardTreeCtrl`:

Method | `Repaint` | Undocumented
Instance Variable | `capindex` | Undocumented
Instance Variable | `cardimageindex` | Undocumented
Instance Variable | `clientpanel` | Undocumented
Instance Variable | `fldrindex` | Undocumented
Instance Variable | `fldropenindex` | Undocumented
Instance Variable | `il` | Undocumented
Instance Variable | `parent` | Undocumented
Instance Variable | `readerimageindex` | Undocumented

def __init__(self, parent, ID=wx.NewId(), pos=wx.DefaultPosition, size=wx.DefaultSize, style=0, clientpanel=None):
overrides `smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.__init__`

Constructor. Create a reader tree control.

def AddATR(self, readernode, atr):

Add an ATR to a reader node.

def GetATR(self, reader):

Return the ATR of the card inserted into the reader.

def OnAddCards(self, addedcards):

Called when a card is inserted. Adds the smart card child to the reader node.

def OnAddReaders(self, addedreaders):

Called when a reader is inserted. Adds the smart card reader to the smartcard readers tree.

def OnRemoveCards(self, removedcards):

Called when a card is removed. Removes the card from the tree.

def OnRemoveReaders(self, removedreaders):

Called when a reader is removed. Removes the reader from the smartcard readers tree.

mutex =

Undocumented

root =

Undocumented